<?php

namespace App\Model;

/**
 * Description of Base
 *
 * @author Monsterboy
 */
class Base extends \Nette\Object 
{
    /** @var Nette\Database\Context */
    public $database;

    /** @var string */
    protected $tableName;

    /** @var \App\Model\Encoding */
    public $encoding;

    public $authorUser = 'user';
    public $authorHousekeeper = 'housekeeper';

    /**
     * @param Nette\Database\Connection $db
     * @throws Nette\InvalidStateException
     */
    public function __construct(\Nette\Database\Context $db)
    {
            $this->database = $db;

            if($this->tableName === NULL) {
                    $class = get_class($this);
                    throw new Nette\InvalidStateException("Název tabulky musí být definován v $class::\$tableName.");
            }
    }
    
    protected function getTable() {
        return $this->database->table($this->tableName);
    }

    /**
     * Vrací všechny záznamy z databáze
     * @return \Nette\Database\Table\Selection
     */
    public function findAll() {
            return $this->getTable();
    }

    /**
     * Vrací vyfiltrované záznamy na základě vstupního pole
     * (pole array('name' => 'David') se převede na část SQL dotazu WHERE name = 'David')
     * @param array $by
     * @return \Nette\Database\Table\Selection
     */
    public function findBy(array $by) {
            return $this->getTable()->where($by);
    }

    /**
     * To samé jako findBy akorát vrací vždy jen jeden záznam
     * @param array $by
     * @return \Nette\Database\Table\ActiveRow|FALSE
     */
    public function findOneBy(array $by) {
            return $this->findBy($by)->limit(1)->fetch();
    }

    /**
     * Vrací záznam s daným primárním klíčem
     * @param int $id
     * @return \Nette\Database\Table\ActiveRow|FALSE
     */
    public function find($id) {
            return $this->getTable()->get($id);
    }
    
    /**
     * Vrací počet nalezených záznamu na základě vstupního pole
     * (pole array('name' => 'David') se převede na část SQL dotazu WHERE name = 'David')
     * @param array $by
     * @return int
     */
    public function countBy(array $by) {
            return $this->getTable()->where($by)->count();
    }
    
    /**
     * Vrací počet nalezených záznamu
     * @return int
     */
    public function count() {
            return $this->getTable()->count();
    }

    /**
     * Upraví záznam
     * @param array $by
     * @param array $data
     */
    public function update($by, $data) {
            $this->findBy($by)->update($data);
    }

    /**
     * Vloží nový záznam a vrátí jeho ID
     * @param array $data
     * @return \Nette\Database\Table\ActiveRow
     */
    public function insert($data) {
            return $this->getTable()->insert($data);
    }

    /**
     * @param $by
     * @return int
     */
    public function delete($by) {
            return $this->getTable()->where($by)->delete();
    }
}
