<?php

namespace App\Model;

use Nette;

/**
 * Manage database table
 *
 * @author Monsterboy
 */
class NewPass extends Base
{
    protected $tableName = 'new_pass';
    public $database;

    function __construct(Nette\Database\Context $database)
    {
        $this->database = $database;
    }

    /**
     *
     *
     * @param $userId
     * @return Nette\Database\Table\ActiveRow
     */
    public function addNewPassRequest($userId = null)
    {
        $data = array();
        $data['users_id'] = $userId;
        $data['valid_from'] = date('Y-m-d H:i:s');
        $data['valid_to'] = date('Y-m-d H:i:s', strtotime("+1 week"));

        $insertedId = $this->insert($data);
        return $insertedId;
    }

    /**
     * Return password request
     * 
     * @param $id
     * @return FALSE|Nette\Database\Table\ActiveRow
     */
    public function getPassRequest($id)
    {
        return $this->find($id);
    }

    /**
     * Check if request for changing password is valid
     *
     * @param $requestId
     * @return bool
     */
    public function isRequestValid($requestId)
    {
        $actDate = date('Y-m-d H:i:s');
        $req = $this->database->query("SELECT id FROM new_pass WHERE id = ? AND valid_from <= ? AND valid_to >= ? AND changed = ?", $requestId, $actDate, $actDate, 0);

        if ($req->getRowCount() > 0)
        {
            return true;
        } 
        else
        {
            return false;
        }
    }

    /**
     * Set request done
     *
     * @param $requestId
     */
    public function setRequestDone($requestId)
    {
        $values = array();
        $values['changed'] = 1;
        $this->update(array('id' => $requestId), $values);
    }
}
