<?php

namespace App\Presenters;

use Nette,
	App\Model;
use Nette\Application\UI\Form;

/**
 * Upravy presenter.
 */
class SettingsPresenter extends BasePresenter
{
    private $actUser;

    public function beforeRender()
    {
        parent::beforeRender();

        if ($this->getUser()->getIdentity())
        {
            $userData = $this->getUser()->getIdentity()->getData();
            if (isset($userData['user_id'])) $this->template->userId = $userData['user_id'];
            else $this->template->userId = null;

            $this->actUser = $this->context->users->getProfileParams($userData['user_id']);
        }
    }

	public function renderDefault()
	{
        if(!$this->user->loggedIn)
        {
            $this->flashMessage('Pokud chcete měnit nastavení, nejprve se musíte přihlásit.','danger');
            $this->redirect('Homepage:default');
        }
	}

	protected function createComponentUser()
	{

        $form = new Form;
        $form->addText('name')
            ->setRequired("Zadejte prosím váše jméno.")
            ->addRule(Form::MIN_LENGTH, 'Zadejte prosím alespoň dva znaky.', 2)
            ->setValue($this->actUser['name']);
        $form->addText('email')
            ->setRequired("Zadejte prosím váš e-mail.")
            ->addRule(Form::EMAIL, 'Zadejte prosím správný formát e-mailu.')
            ->setValue($this->actUser['email']);
        $form->addText('phone')
            ->setRequired("Zadejte prosím váš telefon.")
            ->addRule(Form::PATTERN, 'Telefonní číslo není ve správném tvaru', '^[+]?[()/0-9. -]{9,}$')
            ->setValue($this->actUser['phone']);
        $form->addSubmit('submit');

		$form->onSubmit[] = array($this, 'userSucceeded');
		return $form;
	}

	public function userSucceeded(Form $form)
	{
        if ($this->getUser()->getIdentity())
        {
            $userData = $this->getUser()->getIdentity()->getData();
            if (isset($userData['user_id'])) $this->template->userId = $userData['user_id'];
            else $this->template->userId = null;

            $values = $form->getValues();

            $this->context->users->editUser($userData['user_id'], $values);
            $this->flashMessage('Údaje byli úspěšně změněny.','success');
            $this->redirect("this");
        }
        else
        {
            $this->flashMessage('Pokud chcete měnit nastavení, nejprve se musíte přihlásit.','danger');
            $this->redirect("this");
        }
	}


}
