<?php

namespace App\Model;

use Nette,
    Nette\Security\Passwords;

/**
 * Manage database table housekeeper
 *
 * @author Monsterboy
 */
class Housekeeper extends Base
{
    protected $tableName = 'housekeepers';
    public $database;
    protected $dateTime;
    protected $encodeString;

    function __construct(Nette\Database\Context $database, DateTime $dateTime, EncodingString $enc)
    {
        $this->database = $database;
        $this->dateTime = $dateTime;
        $this->encodeString = $enc;
    }

    /**
     * Ukládá nového klienta
     * 
     * @param array $values Hodnoty z formuláře
     * @return bool
     */
    public function addHousekeeper($value) {

        $this->tableName = 'housekeepers';
            
        $icoDb = array();
        $icoDb['email'] = $value['email'];
        
        $countRows = $this->countBy($icoDb);
        if ($countRows == 0)
        {
            $valuesDB = array();
            $valuesDB['email'] = $value['email'];
            $valuesDB['password'] = Passwords::hash($value['password']);
            $valuesDB['registrated'] = date('Y-m-d H:i:s');
            if (isset($value['role'])) $valuesDB['role'] = $value['role'];
            if (isset($value['agency_id'])) $valuesDB['agency_id'] = $this->encodeString->base64url_decode($value['agency_id']);
            
            $insertedId = $this->insert($valuesDB);
            return $insertedId;
        }
        else 
        {
            return false;
        }
    }

    /**
     * Edit params of housekeeper
     * 
     * @param integer $id ID of client
     * @param array $values values from form
     */
    public function editHousekeeper($id, $values)
    {
        $this->tableName = 'housekeepers';

        $by['housekeeper_id'] = $id;
        $this->update($by, $values);
    }

    /**
     * Return all params about housekeeper
     *
     * @param $id
     * @return FALSE|Nette\Database\Table\ActiveRow
     */
    public function getProfileParams($id)
    {
        $this->tableName = 'housekeepers';

        $row = $this->database->query("SELECT housekeepers.*, agencies.agency_name FROM housekeepers LEFT JOIN agencies ON housekeepers.agency_id=agencies.agency_id WHERE housekeeper_id = ?", $id)->fetch();
        return $row;/*
        $by['housekeeper_id'] = $id;
        return $this->findOneBy($by);*/
    }

    /**
     * Get user ID
     *
     * @param $username
     * @return bool|mixed|Nette\Database\Table\IRow|null
     */
    public function getId($username)
    {
        $this->tableName = 'housekeepers';

        $array = array();
        $array['email'] = $username;

        $row = $this->findOneBy($array);
        return $row['housekeeper_id'];
    }

    /**
     * Return available services id
     *
     * @param $id
     * @return array
     */
    public function getAvailableServicesId($id)
    {
        $this->tableName = 'services_housekeepers';

        $by['housekeeper_id'] = $id;
        $res = $this->findBy($by);
        $servicesArray = array();
        foreach ($res as $service)
        {
            $servicesArray[] = $service['service_id'];
        }
        return $servicesArray;
    }

    /**
     * Set available services id of housekeeper
     *
     * @param $housekeeper_id
     * @param $values
     */
    public function setAvailableServices($housekeeper_id, $services)
    {
        $this->tableName = 'services_housekeepers';

        $by['housekeeper_id'] = $housekeeper_id;
        $this->delete($by);

        foreach ($services as $serviceId)
        {
            $this->insert(array('housekeeper_id' => $housekeeper_id, 'service_id' => $serviceId));
        }
    }

    /**
     * Set last online active
     *
     * @param $id
     */
    public function setLastOnline($id)
    {
        $this->tableName = 'housekeepers';

        $by['housekeeper_id'] = $id;
        $values['last_online'] = date("Y-m-d H:i:s");
        $this->update($by, $values);
    }

    /**
     * Return time last online
     *
     * @param $id Housekeeper ID
     * @return string
     */
    public function getLastOnline($id)
    {
        $this->tableName = 'housekeepers';

        $row = $this->findOneBy(array('housekeeper_id' => $id));
        $actDate = date('Y-m-d H:i:s');
        $lastOnline = date($row->last_online);
        $diff = $this->dateTime->timeDiff($actDate, $lastOnline);
        return $this->dateTime->getTimeInConvenientUnits($diff);
    }

    /**
     * Return age
     *
     * @param $id
     * @return int
     */
    public function getAge($id)
    {
        $this->tableName = 'housekeepers';

        $row = $this->findOneBy(array('housekeeper_id' => $id));
        if ($row['date_birth'])
        {
            $age = $this->dateTime->getAge($row['date_birth']);
        }
        else
        {
            $age = 'XX';
        }
        return $age;
    }

    /**
     * Return rounded rating
     *
     * @param $id
     * @param int $round
     * @return bool|float|Nette\Database\Row
     */
    public function getRating($id, $round = 0)
    {
        $rating = $this->database->query("SELECT AVG(rating) FROM ratings WHERE housekeeper_id = $id AND author = '".$this->authorUser."'")->fetch();
        $rating = round($rating[0], $round);
        return $rating;
    }

    /**
     * Set rating of housekeeper
     *
     * @param $housekeeperId
     * @param $userId
     * @param $rating
     * @param $comment
     */
    public function setRating($housekeeperId, $userId, $rating, $comment)
    {
        $this->tableName = 'ratings';

        $values = array();
        $values['rating'] = $rating;
        $values['comment'] = $comment;
        $values['author'] = $this->authorUser;
        $values['housekeeper_id'] = $housekeeperId;
        $values['user_id'] = $userId;
        $values['assigned'] = date('Y-m-d H:i:s');

        if ($this->countBy(array('user_id' => $userId, 'housekeeper_id' => $housekeeperId)) > 0)
        {
            $data = $this->findOneBy(array('user_id' => $userId, 'housekeeper_id' => $housekeeperId));
            $this->update(array('rating_id' => $data['rating_id']), $values);
        }
        else
        {
            $this->insert($values);
        }
    }

    /**
     * Return housekeepers by accepted distance from inserted lat + lng
     *
     * @param $lat
     * @param $lng
     * @return Array
     */
    public function searchByGeolocation($lat, $lng)
    {
        $distance = "((( 6371 * acos( cos( radians(".$lat.") ) * cos( radians( lat ) ) * cos( radians( lng ) -
        radians(".$lng.") ) + sin( radians(".$lat.") ) * sin( radians( lat ) ) ) ) ) * 1.609344 ) AS distance_between";
        $having = "HAVING distance_between < location_distance";

        $params = array();

        $results = $this->database->query("SELECT *, $distance FROM housekeepers $having ORDER BY distance_between");
        while ($row = $results->fetch())
        {
            $params[$row['housekeeper_id']]['name'] = $row['name'];
            $params[$row['housekeeper_id']]['surname'] = $row['surname'];
            $params[$row['housekeeper_id']]['description'] = $row['description'];
            $params[$row['housekeeper_id']]['city'] = $row['city'];
            $params[$row['housekeeper_id']]['sublocality_level_1'] = $row['sublocality_level_1'];
            $params[$row['housekeeper_id']]['distance_between'] = $row['distance_between'];
            $params[$row['housekeeper_id']]['price_from'] = $row['price_from'];
            $params[$row['housekeeper_id']]['price_to'] = $row['price_to'];
            $params[$row['housekeeper_id']]['rating'] = $this->getRating($row['housekeeper_id'], 0);
            $params[$row['housekeeper_id']]['img_path'] = $this->getPathProfileImage($row['housekeeper_id']);
        }
        return $params;
    }
}
