<?php

namespace App\Model;

use Nette;

/**
 * Manage database table services
 *
 * @author Monsterboy
 */
class Messages extends Base
{
    protected $tableName = 'messages';
    public $database;

    function __construct(Nette\Database\Context $database)
    {
        $this->database = $database;
    }

    /**
     * Send message to housekeeper from user
     *
     * @param $userId
     * @param $housekeeperId
     * @param $message
     */
    public function sendMessage($userId, $housekeeperId, $author, $message)
    {
        $data = array();
        $data['sent'] = date('Y-m-d H:i:s');
        $data['message'] = $message;
        $data['user_id'] = $userId;
        $data['housekeeper_id'] = $housekeeperId;
        $data['author'] = $author;
        $this->insert($data);
    }

    /**
     * Check if user or housekeeper reply on message in thread and return false or datetime
     *
     * @param $housekeeperId
     * @param $userId
     * @param $author
     * @param $sent
     * @return bool|void
     */
    public function getReplyDate($housekeeperId, $userId, $author, $sent)
    {

        $replied = $this->database->query("SELECT sent FROM messages WHERE user_id = ? AND housekeeper_id = ? AND author = ? AND sent > ?",
                                            $userId, $housekeeperId, $author, $sent);

        if (isset($replied))
        {
            $row = $replied->fetch();
            return $row['sent'];
        }
        else
        {
            return false;
        }
    }

    /**
     * Return last message of all conversations
     *
     * @param $userId
     * @return array
     */
    public function getConversationsUser($userId)
    {
        $received = $this->database->query("SELECT t1.*, users.username, housekeepers.name, housekeepers.surname
                                            FROM messages t1
                                            LEFT JOIN users ON t1.user_id=users.user_id
                                            LEFT JOIN housekeepers ON t1.housekeeper_id = housekeepers.housekeeper_id
                                            WHERE t1.message_id = (SELECT t2.message_id
                                                                 FROM messages t2
                                                                 WHERE t2.housekeeper_id = t1.housekeeper_id AND t2.user_id = ?
                                                                 ORDER BY t2.sent DESC
                                                                 LIMIT 1)
                                            ORDER BY sent DESC",
                                            $userId);
        $result = array();

        while ($msg = $received->fetch())
        {
            $result[$msg['message_id']]['message'] = $msg['message'];
            $result[$msg['message_id']]['sent'] = $msg['sent'];
            $result[$msg['message_id']]['read'] = $msg['read'];
            $result[$msg['message_id']]['user_id'] = $msg['user_id'];
            $result[$msg['message_id']]['housekeeper_id'] = $msg['housekeeper_id'];

            $userArray = explode('@', $msg['username']);
            $userName = $userArray[0];

            $surname = substr($msg['surname'], 0, 2).".";

            if ($msg['author'] == $this->authorUser)
            {
                $result[$msg['message_id']]['author'] = $userName." <i class=\"fa fa-long-arrow-right\"></i> ".$msg['name']." ".$surname;
            }
            else
            {
                $result[$msg['message_id']]['author'] = $msg['name']." ".$surname." <i class=\"fa fa-long-arrow-right\"></i> ".$userName;
            }
        }

        return $result;
    }

    /**
     * Return last message of all conversations
     *
     * @param $housekeperId
     * @return array
     */
    public function getConversationsHousekeeper($housekeeperId)
    {
        $received = $this->database->query("SELECT t1.*, users.username, housekeepers.name, housekeepers.surname
                                            FROM messages t1
                                            LEFT JOIN users ON t1.user_id=users.user_id
                                            LEFT JOIN housekeepers ON t1.housekeeper_id = housekeepers.housekeeper_id
                                            WHERE t1.message_id = (SELECT t2.message_id
                                                                 FROM messages t2
                                                                 WHERE t2.housekeeper_id = ? AND t2.user_id = t1.user_id
                                                                 ORDER BY t2.sent DESC
                                                                 LIMIT 1)
                                            ORDER BY sent DESC",
                                            $housekeeperId);
        $result = array();

        while ($msg = $received->fetch())
        {
            $result[$msg['message_id']]['message'] = $msg['message'];
            $result[$msg['message_id']]['sent'] = $msg['sent'];
            $result[$msg['message_id']]['read'] = $msg['read'];
            $result[$msg['message_id']]['user_id'] = $msg['user_id'];
            $result[$msg['message_id']]['housekeeper_id'] = $msg['housekeeper_id'];

            $userArray = explode('@', $msg['username']);
            $userName = $userArray[0];

            $surname = substr($msg['surname'], 0, 2).".";

            if ($msg['author'] == $this->authorUser)
            {
                $result[$msg['message_id']]['author'] = $userName." <i class=\"fa fa-long-arrow-right\"></i> ".$msg['name']." ".$surname;
            }
            else
            {
                $result[$msg['message_id']]['author'] = $msg['name']." ".$surname." <i class=\"fa fa-long-arrow-right\"></i> ".$userName;
            }
        }

        return $result;
    }

    /**
     * Return full conversation between user and housekeeper
     *
     * @param $userId
     * @param $housekeeperId
     * @return Nette\Database\ResultSet
     */
    public function getConversation($userId, $housekeeperId)
    {
        $conversation = $this->database->query("SELECT messages.*, housekeepers.name, housekeepers.surname, users.username
                                                FROM messages
                                                LEFT JOIN users ON messages.user_id=users.user_id
                                                LEFT JOIN housekeepers ON messages.housekeeper_id = housekeepers.housekeeper_id
                                                WHERE messages.housekeeper_id = ? AND messages.user_id = ?
                                                ORDER BY sent DESC",
                                                $housekeeperId, $userId);
        return $conversation;
    }
}
