<?php

namespace App\Model;

use Nette,
	Nette\Utils\Strings,
	Nette\Security\Passwords;


/**
 * Users management.
 */
class UserManager extends Nette\Object implements Nette\Security\IAuthenticator
{
	private $table_name = 'user';
    private $column_id = 'user_id';
    private $column_name = 'name';
    private $column_email = 'email';
    private $column_password_hash  = 'password';

    public function setUserAuthenticate()
    {
        //$this->table_name = 'users';
        $this->column_id = 'user_id';
        $this->column_name = 'name';
        $this->column_email = 'email';
        $this->column_password_hash = 'password';
    }

    /*public function setHousekeeperAuthenticate()
    {
        $this->table_name = 'housekeepers';
        $this->column_id = 'housekeeper_id';
        $this->column_name = 'email';
        $this->column_password_hash = 'password';
    }*/

	/** @var Nette\Database\Context */
	private $database;


	public function __construct(Nette\Database\Context $database)
	{
		$this->database = $database;
	}


	/**
	 * Performs an authentication.
	 * @return Nette\Security\Identity
	 * @throws Nette\Security\AuthenticationException
	 */
	public function authenticate(array $credentials)
	{
        list($username, $password) = $credentials;

        $this->setUserAuthenticate();


		$row = $this->database->table($this->table_name)->where($this->column_email, $username)->fetch();

		if (!$row) {
			throw new Nette\Security\AuthenticationException('Uživatelské jméno neexistuje.', self::IDENTITY_NOT_FOUND);

		} elseif (!Passwords::verify($password, $row[$this->column_password_hash])) {
			throw new Nette\Security\AuthenticationException('Zadané heslo není správné.', self::INVALID_CREDENTIAL);

		} elseif (Passwords::needsRehash($row[$this->column_password_hash])) {
			$row->update(array(
                $this->column_password_hash => Passwords::hash($password),
			));
		}

		$arr = $row->toArray();
		unset($arr[$this->column_password_hash]);
		return new Nette\Security\Identity($row[$this->column_id], null, /*$row[self::COLUMN_ROLE],*/ $arr);
	}

}
