<?php

namespace App\Presenters;

use Nette,
	App\Model;
use Nette\Application\UI\Form;

/**
 * Homepage presenter.
 */
class RegistrationPresenter extends BasePresenter
{
    protected $params;
    private $categories;
    private $subcategories;
    private $make;
    private $model;
    private $area_level_1;

	public function renderDefault()
	{
        if(!$this->user->loggedIn)
        {
            $this->flashMessage('Pro přístup do této sekce se musíte nejprve přihlásit.','warning');
            //$this->redirect('Sign:in');
        }

        $userId = $this->getUser()->getIdentity()->getId();

        $this->template->userId = $userId;

        $this->categories = array_merge(array(""=>"Vyberte kategorii"),$this->context->category->getCategories());
        $this->subcategories = array("" => "Prvně vyberte Kategorii");

        $this->make = array_merge(array(""=>"Vyberte značku"),$this->context->make->getMakes());
        $this->model = array("" => "Prvně vyberte značku");

        $this->area_level_1 = array(1=>"Praha",2=>"Brno");
//        $this->template->availableServices = $this->context->housekeeper->getAvailableServicesId($userId);
//        $this->template->params = $this->context->housekeeper->getProfileParams($userId);
//        $this->template->profileImagePath = $this->context->housekeeper->getPathProfileImage($userId);
	}

	protected function createComponentRegistrace()
	{
        $userId = $this->getUser()->getIdentity()->getId();
        //$this->params = $this->context->housekeeper->getProfileParams($userId);
        $this->params = $this->getUser()->getIdentity();

        if (isset($this->params->date_birth)) $dateBirth = $this->params->date_birth->format('Y-m-d');
        else $dateBirth = '';

		$form = new Form;
        $form->addText('title')
            ->setValue($this->params->title)
            ->setRequired("Zadejte prosím vaše jméno.");
		$form->addText('name')
            ->setValue($this->params->name)
            ->setRequired("Zadejte prosím vaše jméno.");
        $form->addText('phone')
            ->setValue($this->params->phone)
            ->setRequired("Zadejte prosím váš telefon.")->addRule(Form::PATTERN, 'Telefonní číslo není ve správném tvaru', '^[+]?[()/0-9. -]{9,}$');
        $form->addText('price')
            ->setValue($this->params->price)
            ->setRequired("Zadejte prosím cenu.");
        $form->addSelect('area_level_1')->setItems($this->area_level_1)
            ->setRequired('Zvolte prosím kraj.');
        $form->addSelect('category')->setItems($this->categories)
            ->setRequired('Zvolte prosím kategorii.');
        $form->addSelect('subcategory')->setItems($this->subcategories)
            ->setRequired('Zvolte prosím podkategorii.');
        $form->addSelect('make')->setItems($this->make);
        $form->addSelect('model')->setItems($this->model);
		$form->addUpload('photo1')
			->addRule(Form::IMAGE, 'Fotografie musí být JPEG, PNG nebo GIF.')
			->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost souboru je 1 MB.', 1024 * 1024);
        $form->addUpload('photo2')
            ->addRule(Form::IMAGE, 'Fotografie musí být JPEG, PNG nebo GIF.')
            ->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost souboru je 1 MB.', 1024 * 1024);
        $form->addUpload('photo3')
            ->addRule(Form::IMAGE, 'Fotografie musí být JPEG, PNG nebo GIF.')
            ->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost souboru je 1 MB.', 1024 * 1024);
        $form->addUpload('photo4')
            ->addRule(Form::IMAGE, 'Fotografie musí být JPEG, PNG nebo GIF.')
            ->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost souboru je 1 MB.', 1024 * 1024);
        $form->addTextArea('text')
            ->setValue($this->params->text);
		$form->addText('street')
            ->setValue($this->params->street)
            ->setRequired("Zadejte prosím vaši ulici");
		$form->addText('premise')
            ->setValue($this->params->premise);
		$form->addText('street_number')
            ->setValue($this->params->street_number);
		$form->addText('city')
            ->setValue($this->params->city)
            ->setRequired('Zadejte prosím město');
		$form->addText('postcode')
            ->setValue($this->params->postcode)
            ->setRequired('Zadejte prosím PSČ.');
		$form->addText('country')
            ->setValue($this->params->country)
            ->setRequired("Zadejte prosím stát.");
        $form->addText('neighborhood')
            ->setValue($this->params->neighborhood);
        $form->addText('sublocality_level_1')
            ->setValue($this->params->sublocality_level_1);
//        $form->addText('area_level_1')
//            ->setValue($this->params->area_level_1);
        $form->addText('area_level_2')
            ->setValue($this->params->area_level_2);
        $form->addText('location_distance')
            ->setValue($this->params->location_distance);
        $form->addText('lat')
            ->setValue($this->params->lat);
        $form->addText('lng')
            ->setValue($this->params->lng);
        $form->addTextArea('description')
            ->setValue($this->params->description);
        $form->addTextArea('description_service')
            ->setValue($this->params->description_service);
        $form->addText('price_from')
            ->setValue($this->params->price_from);
        $form->addText('price_to')
            ->setValue($this->params->price_to);
        $form->addCheckbox('fulltime')
            ->setValue($this->params->fulltime);
        $form->addCheckbox('parttime')
            ->setValue($this->params->parttime);
        $form->addText('experience_year')
            ->setValue($this->params->experience_year);
        $form->addText('date_birth')
            ->setValue($dateBirth);

        $form->addSubmit('submit');

		$form->onSubmit[] = array($this, 'registrationSucceeded');
		return $form;
	}

	public function registraceSucceeded(Form $form)
	{
        $values = $form->getValues();
        $id = $this->getUser()->getIdentity()->getId();

        $stav = $this->context->uploader->uploadImage($values['photo'], 'housekeeper_'.$id, 'assets/images/housekeepers/');
        unset($values['photo']);

        $this->context->housekeeper->editHousekeeper($id, $values);

        $services = $form->getHttpData($form::DATA_TEXT, 'service[]');
        $this->context->housekeeper->setAvailableServices($id, $services);

        $this->redirect('Homepage:');
	}


}
